.. _api:

API Reference
=============

Generic API
-----------

.. automodule:: pywreck
    :members: Response, request

Method Specific APIs
--------------------

When using HTTP method functions directly, the method string does not have to be specified in the function call parameters.

Supported methods:

* get
* head
* post
* put
* delete
* connect
* options
* trace
* patch
